// The following code is from https://gist.github.com/cferdinandi/6e4a73a69b0ee30c158c8dd37d314663 and is used with thanks

// Core assets, listed in same order used in page

let coreAssets = [

	'jquery-impromptu.css',
	'v1-8-Q-Cogo-Styles.css',
	'fonts/font-awesome-4.4.0/css/font-awesome.min.css',

	'jquery-1.11.1.min.js',
	'jquery-ui.min.js',
	'jquery.hotkeys.js',
	'jquery-impromptu-v6-2-2.js',

	'hammer.min.js',
	
	'v1-8-Q-Cogo-Adjust.js',
	'v1-8-Q-Cogo-Cogo.js',
	'v1-8-Q-Cogo-Misc.js',
	'v1-8-Q-Cogo-Nav.js',
	'v1-8-Q-Cogo-Sketch.js',
	'v1-8-Q-Cogo-Sugg.js',

	'images/v1-8-q-cogo-Logo.gif',
	'images/header.gif',
	'images/DrawingPin1_Blue.png',
	'images/Help_Circle_Blue.png',
	'images/Info_Box_Blue.png',
	'images/Warning.png',
	'images/q-cogo-Logo-card.gif'

];

// On install, cache core assets
self.addEventListener('install', function (event) {

	// Cache core assets
	event.waitUntil(caches.open('app').then(function (cache) {
		for (let asset of coreAssets) {
			cache.add(new Request(asset));
		}
		return cache;
	}));

});

// Listen for request events
self.addEventListener('fetch', function (event) {

	// Get the request
	let request = event.request;

	// Bug fix
	// https://stackoverflow.com/a/49719964
	if (event.request.cache === 'only-if-cached' && event.request.mode !== 'same-origin') return;

	// HTML files
	// Network-first
	if (request.headers.get('Accept').includes('text/html')) {
		event.respondWith(
			fetch(request).then(function (response) {

				// Create a copy of the response and save it to the cache
				let copy = response.clone();
				event.waitUntil(caches.open('app').then(function (cache) {
					return cache.put(request, copy);
				}));

				// Return the response
				return response;

			}).catch(function (error) {

				// If there's no item in cache, respond with a fallback
				return caches.match(request).then(function (response) {
					return response || caches.match('/offline.html');
				});

			})
		);
	}

	// CSS & JavaScript
	// Offline-first
	if (request.headers.get('Accept').includes('text/css') || request.headers.get('Accept').includes('text/javascript')) {
		event.respondWith(
			caches.match(request).then(function (response) {
				return response || fetch(request).then(function (response) {

					// Return the response
					return response;

				});
			})
		);
		return;
	}

	// Images
	// Offline-first
	if (request.headers.get('Accept').includes('image')) {
		event.respondWith(
			caches.match(request).then(function (response) {
				return response || fetch(request).then(function (response) {

					// Save a copy of it in cache
					let copy = response.clone();
					event.waitUntil(caches.open('app').then(function (cache) {
						return cache.put(request, copy);
					}));

					// Return the response
					return response;

				});
			})
		);
	}

});